#!/usr/bin/sh

#ident "@(#)opensrc:cups-1.1.19/cups-1.1.19.sh /main/uw713up/uw713up3bl3/1"

#
# The source here is from cups-1.1.19 distribution except for:
#
# - cups-1.1.19.sh (this file)
# - cups-1.1.19.depend (depend file for build script)
# - cups.1.1.19-unixware.patch (patch file)
# - chprnsys.sh (script to switch print system)
# - chprnsys.8 (man page for chprnsys)
# - printerGUI (scoadmin piece)
# - printjobGUI (scoadmin piece)
#

set -x
set -e

# Apply patches.
for patch in cups-1.1.19-unixware.patch
do
	[ -f .${patch}.applied ] || {
		/bin/patch -c -p0 -i ${patch}
		/bin/date > .${patch}.applied
	}
done

# CUPS need BSD-compatible install command.
INSTALL="/usr/ucb/install"
if [ ! -x ${INSTALL} ]
then
	echo "ERROR: ${INSTALL} not found." >&2
	exit 1
fi
export INSTALL

# Override test for "ar" and "strip" by defining absolute pathnames.
AR=${TOOLS}/usr/ccs/bin/${AR}
STRIP=${TOOLS}/usr/ccs/bin/${STRIP}
export AR STRIP

#
# Execute ./configure with options tailored for UnixWare.
#
# Set --host=i386 otherwise configure will try to execute a.out and fail
# since i386cc produces i386a.out.
#
# Support for libz, libjeg, libpng, and libtiff is enabled by default.
# Support for openssl is explicitly enabled.
#
# The libraries and header files should be in xenv.
#
# Support for openslp is explicitly enabled.  Openslp has been ported but
# is not yet part of nightly build, and hence we rely on the package being
# installed on build machine.  We copy libraries and header files from
# build machine to xenv so that compiler/linker finds them.
#

if /bin/pkginfo -q openslp
then
	/bin/cp -f /usr/include/slp.h ${TOOLS}/usr/include
	/bin/cp -f /usr/lib/libslp.so.1.0.0 ${TOOLS}/usr/lib
	/bin/rm -f ${TOOLS}/usr/lib/libslp.so
	/bin/rm -f ${TOOLS}/usr/lib/libslp.so.1
	/bin/ln -f -s libslp.so.1.0.0 ${TOOLS}/usr/lib/libslp.so
	/bin/ln -f -s libslp.so.1.0.0 ${TOOLS}/usr/lib/libslp.so.1
else
	echo "ERROR: openslp not installed." >&2
	exit 1
fi

./configure \
	--host=i386 \
	--prefix= \
	--exec_prefix=/usr \
	--includedir=\${prefix}/usr/include \
	--bindir=\${exec_prefix}/lib/cups/bin \
	--datadir=\${prefix}/usr/share \
	--sbindir=\${exec_prefix}/lib/cups/sbin \
	--mandir=\${exec_prefix}/lib/cups/man \
	--with-docdir=\${prefix}/usr/share/cups/doc \
	--disable-libpaper \
	--disable-gnutls \
	--disable-cdsassl \
	--disable-pam \
	--enable-slp \
	--enable-ssl \
	--with-java=/usr/java/bin/java \
	--with-perl=/usr/bin/perl \
	--without-php \
	--without-python

# Make sure support for all add-on libraries was added.
if [ -z "`./cups-config --image --libs |
	/bin/grep -- -lz |
	/bin/grep -- -ljpeg |
	/bin/grep -- -lpng |
	/bin/grep -- -ltiff |
	/bin/grep -- -lslp |
	/bin/grep -- -lssl |
	/bin/grep -- -lcrypto |
	/bin/grep -- -lsocket`" ]
then
	echo "ERROR: one or more required libraries not found." >&2
	exit 1
fi

#
# Make everything.
# _unixware define is right now used by backend/parallel.c and backend/serial.c
# only.
#
${MAKE} RC_CFLAGS=-D_unixware

# Install header files in cross environment.
${MAKE} DSTROOT=${TOOLS} RC_CFLAGS=-D_unixware installhdrs

#
# Install libraries in cross environment.
# Makefiles do not provide convenient installibs tags.
#
${INSTALL} -d ${TOOLS}/usr/lib
${INSTALL} -m 755 cups/libcups.a ${TOOLS}/usr/lib
${INSTALL} -m 755 cups/libcups.so.2 ${TOOLS}/usr/lib
${INSTALL} -m 755 filter/libcupsimage.a ${TOOLS}/usr/lib
${INSTALL} -m 755 filter/libcupsimage.so.2 ${TOOLS}/usr/lib
/bin/rm -f ${TOOLS}/usr/lib/libcups.so
/bin/rm -f ${TOOLS}/usr/lib/libcupsimage.so
/bin/ln -s ${TOOLS}/usr/lib/libcups.so.2 ${TOOLS}/usr/lib/libcups.so
/bin/ln -s ${TOOLS}/usr/lib/libcupsimage.so.2 ${TOOLS}/usr/lib/libcupsimage.so

# Install everything in ${ROOT}/${MACH}.
${MAKE} DSTROOT=${ROOT}/${MACH} RC_CFLAGS=-D_unixware install

# Install chprnsys script and its man page.
${INSTALL} -d ${ROOT}/${MACH}/usr/sbin
${INSTALL} -d ${ROOT}/${MACH}/usr/man/man.8
${INSTALL} -m 500 chprnsys.sh ${ROOT}/${MACH}/usr/sbin/chprnsys
${INSTALL} -m 444 chprnsys.8 ${ROOT}/${MACH}/usr/man/man.8

# Install scoadmin pieces.
${INSTALL} -d ${ROOT}/${MACH}/usr/lib/cups/scoadmin
${INSTALL} -m 555 printerGUI ${ROOT}/${MACH}/usr/lib/cups/scoadmin
${INSTALL} -m 555 printjobGUI ${ROOT}/${MACH}/usr/lib/cups/scoadmin

# Install metadata files for docview.
PR_group=/usr/share/meta/doc/HelpTopics/PRhome/PRgroup

${INSTALL} -d ${ROOT}/${MACH}/${PR_group}

# English
/bin/cat > ${ROOT}/${MACH}/${PR_group}/PR_cups.desktop << EOF
[Desktop Entry]
Name=Common UNIX Print Subsystem (CUPS)
DocPath=/usr/share/doc/unixware/en/cups/documentation.html
X-COL-rewrite=cups
EOF

# German
/bin/cat > ${ROOT}/${MACH}/${PR_group}/PR_cups.de.desktop << EOF
[Desktop Entry]
Name=Common UNIX Print Subsystem (CUPS)
DocPath=/usr/share/doc/unixware/de/cups/documentation.html
X-COL-rewrite=cups
EOF

# French
/bin/cat > ${ROOT}/${MACH}/${PR_group}/PR_cups.fr.desktop << EOF
[Desktop Entry]
Name=Common UNIX Print Subsystem (CUPS)
DocPath=/usr/share/doc/unixware/fr/cups/documentation.html
X-COL-rewrite=cups
EOF

#
# Move man pages to Unix standard directories.
# We are not modifying configure script since this is UnixWare specific
# change and have no chance of being bought back.
#

# Move all files from directory $1 to $2.
_mv()
{       
	[ ! -d $2 ] && mkdir -p $2
	/bin/ls $1 | /bin/xargs -i /bin/mv -f $1/{} $2/{}
}

# We have only English and French man pages now.
for lang in ' ' fr
do
	cd ${ROOT}/${MACH}/usr/lib/cups/man/${lang}

	_mv man1 man.1
	_mv man3 man.3
	_mv man5 man.5
	_mv man8 man.8

	# We do not need cat pages - identical to man pages.
	# _mv cat1 cat.1
	# _mv cat3 cat.3
	# _mv cat5 cat.5
	# _mv cat8 cat.8

	/bin/rm -rf cat1 cat3 cat5 cat8 man1 man3 man5 man8
done
